pub struct Split {
pub date: i64,
pub numerator: Decimal,
pub denominator: Decimal,
pub split_ratio: String,
}Expand description
This structure simply models a split that has occured.
Fields
date: i64This is the date (timestamp) when the split occured
numerator: DecimalNumerator of the split. For instance a 1:5 split means you get 5 share wherever you had one before the split. (Here the numerator is 1 and denom is 5). A reverse split is considered as nothing but a regular split with a numerator > denom.
denominator: DecimalDenominator of the split. For instance a 1:5 split means you get 5 share wherever you had one before the split. (Here the numerator is 1 and denom is 5). A reverse split is considered as nothing but a regular split with a numerator > denom.
split_ratio: StringA textual representation of the split.